searchNodes=[{"ref":"Sandbox.html","title":"Sandbox","type":"module","doc":"--- Warning --- This library is under heavy development and will have breaking changes until the 1.0.0 release. Sandbox provides restricted, isolated scripting environments for Elixir through the use of embedded Lua. This project is powered by Robert Virding&#39;s amazing Luerl, an Erlang library that lets one execute Lua scripts on the BEAM. Luerl executes Lua code without running a Lua VM as a separate application! Rather, the state of the VM is used as a data structure that can be externally manipulated and processed. The :luerl_sandbox module is utilized wherever possible. This limits access to dangerous core libraries. It also permits Lua scripts to be run with enforced CPU reduction limits. To work with Lua&#39;s full library, use Sandbox.unsafe_init/0 as opposed to Sandbox.init/0. Conventions followed in this library: Functions beginning with eval return a result from Lua. Functions starting with play return a new Lua state. Functions preceded by run return a tuple of {result, new_state} All functions return ok-error tuples such as {:ok, value} or {:error, reason} unless followed by a bang. Elixir functions exposed to Lua take two arguments: a Lua state and a list of Lua arguments. They should return a value corresponding to the eval, play or run responses. The max_reductions argument defaults to 0, corresponding to unlimited reductions."},{"ref":"Sandbox.html#chunk/2","title":"Sandbox.chunk/2","type":"function","doc":"Create a compiled chunk of Lua code that can be transferred between Lua states, returned in an ok-error tuple."},{"ref":"Sandbox.html#chunk!/2","title":"Sandbox.chunk!/2","type":"function","doc":"Same as chunk/2, but will return the raw result or raise a RuntimeError."},{"ref":"Sandbox.html#eval/3","title":"Sandbox.eval/3","type":"function","doc":"Evaluates a Lua string or chunk against the given Lua state and returns the result in an ok-error tuple. The state itself is not modified. Examples iex&gt; Sandbox.init() |&gt; Sandbox.eval(&quot;return 3 + 4&quot;) {:ok, 7.0} iex&gt; Sandbox.init() |&gt; Sandbox.eval(&quot;return math.floor(9.9)&quot;) {:ok, 9.0}"},{"ref":"Sandbox.html#eval!/3","title":"Sandbox.eval!/3","type":"function","doc":"Same as eval/3, but will return the raw result or raise a RuntimeError. Examples iex&gt; Sandbox.init() |&gt; Sandbox.eval!(&quot;return 3 + 4&quot;) 7.0 iex&gt; Sandbox.init() |&gt; Sandbox.eval!(&quot;return math.floor(9.9)&quot;) 9.0"},{"ref":"Sandbox.html#eval_file/3","title":"Sandbox.eval_file/3","type":"function","doc":"Evaluates a Lua file against the given Lua state and returns the result in an ok-error tuple. The state itself is not modified."},{"ref":"Sandbox.html#eval_file!/3","title":"Sandbox.eval_file!/3","type":"function","doc":"Same as eval_file/3, but will return the raw result or raise a RuntimeError."},{"ref":"Sandbox.html#eval_function!/4","title":"Sandbox.eval_function!/4","type":"function","doc":"Calls a function defined in the the Lua state and returns only the result. The state itself is not modified. Lua functions in the Lua state can be referenced by their lua_path, being a string or list such as math.floor or [&quot;math&quot;, &quot;floor&quot;]."},{"ref":"Sandbox.html#get!/2","title":"Sandbox.get!/2","type":"function","doc":"Gets a value from a Lua state."},{"ref":"Sandbox.html#init/0","title":"Sandbox.init/0","type":"function","doc":"Creates a Lua state with &quot;dangerous&quot; core library features such as file IO and networking removed."},{"ref":"Sandbox.html#let_elixir_eval!/3","title":"Sandbox.let_elixir_eval!/3","type":"function","doc":"Returns a Lua state modified to include an Elixir function, elixir_eval_fun(), at the given lua_path(). The elixir_eval_fun() takes two arguments, a Lua state and a list of calling arguments from Lua. Its return value is passed along to Lua. It will not mutate the Lua state against which it executes."},{"ref":"Sandbox.html#let_elixir_play!/3","title":"Sandbox.let_elixir_play!/3","type":"function","doc":"Returns a Lua state modified to include an Elixir function, elixir_play_fun(), at the given lua_path(). The elixir_play_fun() takes two arguments, a Lua state and a list of calling arguments from Lua. It should return a new Lua state. This can be used to let Lua scripts use something like controlled inheritance, dynamically adding external functionality and settings."},{"ref":"Sandbox.html#let_elixir_run!/3","title":"Sandbox.let_elixir_run!/3","type":"function","doc":"Returns a Lua state modified to include an Elixir function, elixir_run_fun(), at the given lua_path(). The elixir_run_fun() takes two arguments, a Lua state and a list of calling arguments from Lua. It should return a tuple holding the result intended for the calling Lua function alongside a new Lua state."},{"ref":"Sandbox.html#play/3","title":"Sandbox.play/3","type":"function","doc":"Runs a Lua string or chunk against a Lua state and returns a new Lua state in an ok-error tuple."},{"ref":"Sandbox.html#play!/3","title":"Sandbox.play!/3","type":"function","doc":"Same as play/3, but will return the raw result or raise a RuntimeError."},{"ref":"Sandbox.html#play_file!/3","title":"Sandbox.play_file!/3","type":"function","doc":"Runs a Lua file in the context of a Lua state and returns a new Lua state."},{"ref":"Sandbox.html#play_function!/4","title":"Sandbox.play_function!/4","type":"function","doc":"Runs a Lua function defined in the given Lua state and returns a new Lua state."},{"ref":"Sandbox.html#run/3","title":"Sandbox.run/3","type":"function","doc":"Runs a Lua string or chunk against the given Lua state and returns the result and the new Lua state in an ok-error tuple."},{"ref":"Sandbox.html#run!/3","title":"Sandbox.run!/3","type":"function","doc":"Same as run/3, but will return the raw {result, state} or raise a RuntimeError."},{"ref":"Sandbox.html#run_function!/4","title":"Sandbox.run_function!/4","type":"function","doc":"Runs a function defined in the the Lua state and returns the result and the new Lua state as {result, state}. Lua functions in the Lua state can be referenced by their lua_path, a string or list such as math.floor or [&quot;math&quot;, &quot;floor&quot;]."},{"ref":"Sandbox.html#set!/4","title":"Sandbox.set!/4","type":"function","doc":"Sets a value in a Lua state and returns the modified state. If force is set to true, new tables will be created automatically if they missing from the given lua_path."},{"ref":"Sandbox.html#unsafe_init/0","title":"Sandbox.unsafe_init/0","type":"function","doc":"Creates a Lua state with access to Lua&#39;s standard library. The max_reductions feature of Sandbox is still available, but &quot;dangerous&quot; core library features such as file IO and networking are still available."},{"ref":"Sandbox.html#t:elixir_eval_fun/0","title":"Sandbox.elixir_eval_fun/0","type":"type","doc":"An Elixir function that can be invoked through Lua. It takes a Lua state and a list of Lua arguments and returns a result. The Lua state acts as a context but is not modified."},{"ref":"Sandbox.html#t:elixir_play_fun/0","title":"Sandbox.elixir_play_fun/0","type":"type","doc":"An Elixir function that can be invoked through Lua. It takes a Lua state and a list of Lua arguments and returns a new Lua state. The result of this function is not exposed to Lua."},{"ref":"Sandbox.html#t:elixir_run_fun/0","title":"Sandbox.elixir_run_fun/0","type":"type","doc":"An Elixir function that can be invoked through Lua. It takes a Lua state and a list of Lua arguments and returns a tuple containing a result and a new Lua state."},{"ref":"Sandbox.html#t:lua_chunk/0","title":"Sandbox.lua_chunk/0","type":"type","doc":"Compiled Lua code that can be transferred between Lua states."},{"ref":"Sandbox.html#t:lua_code/0","title":"Sandbox.lua_code/0","type":"type","doc":"Lua code as either a raw string or compile chunk."},{"ref":"Sandbox.html#t:lua_path/0","title":"Sandbox.lua_path/0","type":"type","doc":"A dot-delimited name or list of names representing a table path in Lua such as math.floor or [&quot;math&quot;, &quot;floor&quot;]."},{"ref":"Sandbox.html#t:lua_state/0","title":"Sandbox.lua_state/0","type":"type","doc":"The representation of an entire Lua virtual machine and its current state."},{"ref":"Sandbox.html#t:lua_value/0","title":"Sandbox.lua_value/0","type":"type","doc":"Lua values represented as Elixir data structures."}]